package j2d.imageBrowser;

/**
 * Copyright 2005, DocJava, Inc.
 * User: dlyon
 * Date: Jan 23, 2006
 * Time: 4:11:12 PM
 */

import futils.ListImageFiles;
import gui.run.RunMenu;
import gui.run.RunMenuBar;
import gui.run.RunMenuItem;
import j2d.ImageUtils;
import j2d.Images;

import javax.swing.*;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import java.awt.*;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.util.Vector;

//SplitPaneDemo itself is not a visible component.

public class ImageBrowser implements ListSelectionListener
{
    private Vector imageFileVector;
    private JLabel picture;
    private JList jListOfImageNames;
    private JSplitPane splitPane;
    private JFrame frame;

    public ImageBrowser()
    {
        //Provide minimum sizes for the two components in the split pane
        Dimension minimumSize = new Dimension( 100, 50 );

        populateImgList( minimumSize );

        //Provide a preferred size for the split pane
        splitPane.setPreferredSize( new Dimension( 400, 200 ) );
    }

    private JList getJList()
    {
        JList jl = new JList( getFileNames( imageFileVector ) );
        jl.setSelectionMode( ListSelectionModel.SINGLE_SELECTION );
        jl.setSelectedIndex( 0 );
        jl.addListSelectionListener( this );
        return jl;
    }

    private Vector getImageFiles()
    {
        File f[] = ListImageFiles.getImgFileList( "Select an image directory" );
        Vector v = new Vector();

        System.out.println( "Length of img file list is " + f.length );

        for ( int i = 0; i < f.length; i++ )
        {
            v.addElement( f[i] );
        }

        return v;
    }

    public JSplitPane getSplitPane()
    {
        return splitPane;
    }

    public void valueChanged( ListSelectionEvent e )
    {
        if ( e.getValueIsAdjusting() )
        {
            return;
        }

        JList theList = (JList) e.getSource();
        if ( theList.isSelectionEmpty() )
        {
            picture.setIcon( null );
        }
        else
        {
            int index = theList.getSelectedIndex();
            String filename = imageFileVector.elementAt( index ).toString();
            ImageIcon newImage = new ImageIcon( filename );
            picture.setIcon( newImage );
            picture.setPreferredSize( new Dimension( newImage.getIconWidth(),
                    newImage.getIconHeight() ) );
            picture.revalidate();
        }
    }

    public JMenuBar getMenuBar()
    {
        RunMenuBar mb = new RunMenuBar();
        mb.add( getFileMenu() );
        return mb;
    }

    public RunMenu getFileMenu()
    {
        RunMenu fileMenu = new RunMenu( "[File" );
        fileMenu.add( new RunMenuItem( "View [Thumbs" )
        {
            public void run()
            {
                appendImages();
            }

        } );
        fileMenu.add( new RunMenuItem( "[quit{control q}" )
        {
            public void run()
            {
                System.exit( 0 );
            }
        } );
        return fileMenu;
    }

    private void appendImages()
    {
        Image[] img = getImages();
        String[] imgNames = getListImgNames();

        ImageThumbViewer itv = new ImageThumbViewer( img, imgNames );
    }

    public Image[] getImages()
    {
        Images imgs = new Images();
        for ( int i = 0; i < imageFileVector.size(); i++ )
        {
            File x = (File) imageFileVector.elementAt( i );
            System.out.println( x );
            if ( x.isFile() )
            {
                Image image = ImageUtils.getImage( x );
                if ( image != null ) imgs.add( image );
            }
        }
        return imgs.getImages();
    }

    public String[] getListImgNames()
    {
        Vector v = getFileNames( imageFileVector );

        String[] listNames = new String[v.size()];

        for ( int i = 0; i < v.size(); i++ )
        {
            listNames[i] = (String) v.elementAt( i );
        }

        return listNames;
    }

    private Vector getFileNames( Vector imageNames )
    {
        Vector v = new Vector();
        for ( int i = 0; i < imageNames.size(); i++ )
        {
            File f = (File) imageNames.elementAt( i );
            v.addElement( f.getName() );
        }
        return v;
    }

    public void start()
    {
        frame = new JFrame( "Image Browser" );
        frame.setJMenuBar( getMenuBar() );
        frame.addWindowListener( new WindowAdapter()
        {
            public void windowClosing( WindowEvent e )
            {
                System.exit( 0 );
            }
        } );

        frame.getContentPane().add( getSplitPane() );
        frame.pack();
        frame.setVisible( true );
    }

    private void populateImgList( Dimension _minimumSize )
    {
        imageFileVector = getImageFiles();

        //Create the jListOfImageNames of images and put it in a scroll pane
        jListOfImageNames = getJList();
        JScrollPane listScrollPane = new JScrollPane( jListOfImageNames );

        //Set up the picture label and put it in a scroll pane
        ImageIcon firstImage = new ImageIcon( imageFileVector.firstElement().toString() );
        picture = new JLabel( firstImage );
        picture.setPreferredSize( new Dimension( firstImage.getIconWidth(),
                firstImage.getIconHeight() ) );
        JScrollPane pictureScrollPane = new JScrollPane( picture );

        //Create a split pane with the two scroll panes in it
        splitPane = new JSplitPane( JSplitPane.HORIZONTAL_SPLIT,
                listScrollPane, pictureScrollPane );
        splitPane.setOneTouchExpandable( true );
        splitPane.setDividerLocation( 150 );

        listScrollPane.setMinimumSize( _minimumSize );
        pictureScrollPane.setMinimumSize( _minimumSize );
    }

    public static void main( String s[] )
    {
        try
        {
            //set the look and feel to the system look and feel for prettiness
            UIManager.setLookAndFeel(
                    UIManager.getSystemLookAndFeelClassName() );
        }
        catch ( Exception e )
        {
            System.out.println( e );
        }

        ImageBrowser ib = new ImageBrowser();
        ib.start();
    }
}


